@@ -1,6 +1,6 @@
-#' Conduct one simulation using the Calibration-free odds (CFO) or accumulative CFO (aCFO) design.
+#' Conduct one simulation using the calibration-free odds (CFO) or accumulative CFO (aCFO) design for phase I trials.
 #' 
-#' In the CFO and aCFO designs, the function is used to conduct one single simulation and find the maximum tolerated dose (MTD).
+#' In the CFO and aCFO designs for phase I trials, the function is used to conduct one single simulation and find the maximum tolerated dose (MTD).
 #'
 #' @usage CFO.simu(design, target, p.true, init.level = 1, ncohort, cohortsize,
 #'        prior.para = list(alp.prior = target, bet.prior = 1 - target), 
@@ -33,10 +33,10 @@
 #'         \itemize{
 #'         \item target: the target DLT rate.
 #'         \item MTD: the selected MTD. \code{MTD = 99} indicates that the simulation is terminated due to early stopping.
-#'         \item correct: a binary indicator of whether the recommended dose level matches the target DLT rate (1 for yes).
+#'         \item correct: a binary indicator of whether the recommended dose level matches the correct MTD (1 for yes).
+#'               The correct MTD is the dose level at which the true DLT rate is closest to the target DLT rate.
 #'         \item npatients: the total number of patients allocated to all dose levels.
 #'         \item ntox: the total number of DLTs observed for all dose levels.
-#'         \item npercent: the percentage of subjects assigned to the target DLT rate.
 #'         \item over.doses: a vector indicating whether each dose is overdosed or not (1 for yes).
 #'         \item cohortdose: a vector including the dose level assigned to each cohort.
 #'         \item ptoxic: the percentage of subjects assigned to dose levels with a DLT rate greater than the target.
@@ -45,7 +45,7 @@
 #'         \item earlystop: a binary indicator of whether the trial is early stopped (1 for yes).
 #'         }
 #' 
-#' @author Jialu Fang, Wenliang Wang, and Guosheng Yin
+#' @author Jialu Fang, Wenliang Wang, Ninghao Zhang, and Guosheng Yin
 #' 
 #' @references Jin H, Yin G (2022). CFO: Calibration-free odds design for phase I/II clinical trials.
 #'             \emph{Statistical Methods in Medical Research}, 31(6), 1051-1066. \cr
@@ -95,6 +95,15 @@ CFO.simu <- function(design, target, p.true, init.level=1, ncohort, cohortsize,
       return(FALSE)
     }
   }
+  
+  MTD.level <- function(phi, p.true){
+    if (p.true[1]>phi+0.1){
+      MTD <- 99
+      return(MTD)
+    }
+    MTD <- which.min(abs(phi - p.true))
+    return(MTD)
+  }
   ###############################################################################
   ############################MAIN DUNCTION######################################
   ###############################################################################
@@ -177,15 +186,15 @@ CFO.simu <- function(design, target, p.true, init.level=1, ncohort, cohortsize,
     MTD <- 99
   }
   
+  tmtd <- MTD.level(target, p.true)
   correct <- 0
-  if (MTD == target){
+  if (MTD == tmtd){
     correct <- 1
   }
   
-  npercent <- ans[which(p.true == target)]/(ncohort*cohortsize)
   ptoxic <- sum(ans[which(p.true > target)])/(ncohort*cohortsize)
   
-  out<-list(target=target, MTD=MTD, correct=correct, npatients=ans, ntox=ays, npercent=npercent, 
+  out<-list(target=target, MTD=MTD, correct=correct, npatients=ans, ntox=ays,
             over.doses=tover.doses, cohortdose=doselist, ptoxic=ptoxic, patientDLT=DLTlist,
             sumDLT=sum(DLTlist), earlystop=earlystop)
   class(out) <- c("cfo_trial", "cfo")
